==> pegasus-support-2.3.0-sources.jar: com/thebeastshop/support/vo/lottery/LotteryAwardVO.java <==
package com.thebeastshop.support.vo.lottery;

import java.io.Serializable;
import java.util.List;

/**
 * 抽奖奖项
 * Created by feilong.gao on 2016/12/6.
 */
public class LotteryAwardVO implements Serializable {

    /**
     * serialVersionUID
     */
    private static final long serialVersionUID = 1L;

    /**
     * 奖项id
     */
    private Long awardId;

    /**
     * 奖项名字
     */
    private String awardName;

    /**
     * 奖品列表
     */
    private List<LotteryPrizeVO> prizes;

    /**
     * 中奖描述
     */
    private String content;

    public Long getAwardId() {
        return awardId;
    }

    public void setAwardId(Long awardId) {
        this.awardId = awardId;
    }

    public String getAwardName() {
        return awardName;
    }

    public void setAwardName(String awardName) {
        this.awardName = awardName;
    }

    public List<LotteryPrizeVO> getPrizes() {
        return prizes;
    }

    public void setPrizes(List<LotteryPrizeVO> prizes) {
        this.prizes = prizes;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    @Override
    public String toString() {
        final StringBuffer sb = new StringBuffer("LotteryAwardVO{");
        sb.append("awardId=").append(awardId);
        sb.append(", awardName='").append(awardName).append('\'');
        sb.append(", prizes=").append(prizes);
        sb.append(", content='").append(content).append('\'');
        sb.append('}');
        return sb.toString();
    }
}

==> pegasus-support-2.6.13-sources.jar: com/thebeastshop/support/vo/lottery/LotteryAwardVO.java <==
package com.thebeastshop.support.vo.lottery;

import java.io.Serializable;
import java.util.List;

/**
 * 抽奖奖项
 * Created by feilong.gao on 2016/12/6.
 */
public class LotteryAwardVO implements Serializable {

    /**
     * serialVersionUID
     */
    private static final long serialVersionUID = 1L;

    /**
     * 奖项id
     */
    private Long awardId;

    /**
     * 奖项名字
     */
    private String awardName;

    /**
     * 奖品列表
     */
    private List<LotteryPrizeVO> prizes;

    /**
     * 中奖描述
     */
    private String content;


    /**
     * 分享图地址
     */
    private String shareImgUrl;
    /**
     * 生成背景图地址
     */
    private String bgImgUrl;

    public String getShareImgUrl() {
        return shareImgUrl;
    }

    public void setShareImgUrl(String shareImgUrl) {
        this.shareImgUrl = shareImgUrl;
    }

    public String getBgImgUrl() {
        return bgImgUrl;
    }

    public void setBgImgUrl(String bgImgUrl) {
        this.bgImgUrl = bgImgUrl;
    }

    public Long getAwardId() {
        return awardId;
    }

    public void setAwardId(Long awardId) {
        this.awardId = awardId;
    }

    public String getAwardName() {
        return awardName;
    }

    public void setAwardName(String awardName) {
        this.awardName = awardName;
    }

    public List<LotteryPrizeVO> getPrizes() {
        return prizes;
    }

    public void setPrizes(List<LotteryPrizeVO> prizes) {
        this.prizes = prizes;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    @Override
    public String toString() {
        return "LotteryAwardVO{" +
                "awardId=" + awardId +
                ", awardName='" + awardName + '\'' +
                ", prizes=" + prizes +
                ", content='" + content + '\'' +
                ", shareImgUrl='" + shareImgUrl + '\'' +
                ", bgImgUrl='" + bgImgUrl + '\'' +
                '}';
    }
}
